@@ -42,11 +42,9 @@ class Integer(Value):
         a = ArtifactModel(
             header=self.build_artifact_header(),
             body=ValueModel(
-                artifact_type=ArtifactType.VALUE,
                 metadata=self.metadata,
                 value_class=self.get_class_path(),
                 value=IntegerValueModel(
-                    value_type=ValueType.INTEGER,
                     integer=self.value,
                 ),
             ),
@@ -75,11 +73,7 @@ class Integer(Value):
         """Comparison between Integer values."""
         if not isinstance(other, Integer):
             return False
-        return self.value == other.value
-
-    def __neq__(self, other: Integer) -> bool:
-        """Comparison between Integer values."""
-        return not self.__eq__(other)
+        return self._equal(other)
 
     def __str__(self) -> str:
         """Return a string representation of the Integer."""
